@@ -2,7 +2,7 @@ from .metrics_model import MetricModel
 
 def build_metric_model(metric_id, metric_name, org_id, component_id, 
     namespace, metric_alignment, agent, dimensions, region_name=None,
-    is_default=False, description=None, period=60,unit=None, samples=[]):
+    is_active=False, is_active_test=False, description=None, period=60,unit=None, samples=[]):
   return MetricModel(
     metric_id=metric_id,
     metric_name=metric_name, 
@@ -16,7 +16,8 @@ def build_metric_model(metric_id, metric_name, org_id, component_id,
     metric_alignment = metric_alignment,
     unit = unit,
     description = description,
-    is_default = is_default,
+    is_active = is_active,
+    is_active_test = is_active_test,
     samples=[]
   )
 
